@@ -73,6 +73,12 @@ from .sqlite_utils import CollatingSequences
 @click.option(
     "-X", "--without-foreign-keys", is_flag=True, help="Do not transfer foreign keys."
 )
+@click.option(
+    "-W",
+    "--without-data",
+    is_flag=True,
+    help="Do not transfer table data, DDL only.",
+)
 @click.option(
     "-h", "--mysql-host", default="localhost", help="MySQL host. Defaults to localhost."
 )
@@ -90,6 +96,7 @@ from .sqlite_utils import CollatingSequences
     help="Chunk reading/writing SQL records",
 )
 @click.option("-l", "--log-file", type=click.Path(), help="Log file")
+@click.option("--json-as-text", is_flag=True, help="Transfer JSON columns as TEXT.")
 @click.option(
     "-V",
     "--vacuum",
@@ -119,11 +126,13 @@ def cli(
     collation,
     prefix_indices,
     without_foreign_keys,
+    without_data,
     mysql_host,
     mysql_port,
     skip_ssl,
     chunk,
     log_file,
+    json_as_text,
     vacuum,
     use_buffered_cursors,
     quiet,
@@ -141,10 +150,12 @@ def cli(
             prefix_indices=prefix_indices,
             without_foreign_keys=without_foreign_keys
             or (mysql_tables is not None and len(mysql_tables) > 0),
+            without_data=without_data,
             mysql_host=mysql_host,
             mysql_port=mysql_port,
             mysql_ssl_disabled=skip_ssl,
             chunk=chunk,
+            json_as_text=json_as_text,
             vacuum=vacuum,
             buffered=use_buffered_cursors,
             log_file=log_file,
